This is a read-only variant of the `FCALL` command that cannot execute commands that modify data.

For more information about when to use this command vs `FCALL`, please refer to [Read-only scripts](/docs/manual/programmability/#read-only_scripts).

For more information please refer to [Introduction to Redis Functions](/topics/functions-intro).
